@@ -4,16 +4,14 @@ Main interface for imagebuilder service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_imagebuilder import (
         Client,
         imagebuilderClient,
     )
 
-    session = boto3.Session()
-
-    client: imagebuilderClient = boto3.client("imagebuilder")
-    session_client: imagebuilderClient = session.client("imagebuilder")
+    session = Session()
+    client: imagebuilderClient = session.client("imagebuilder")
     ```
 """
 from .client import imagebuilderClient
