@@ -552,7 +552,8 @@ class imagebuilderClient(BaseClient):
         nextToken: str = ...
     ) -> ListComponentsResponseTypeDef:
         """
-        Returns the list of component build versions for the specified semantic version.
+        Returns the list of components that can be filtered by name, or by using the
+        listed `filters` to streamline results.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/imagebuilder.html#imagebuilder.Client.list_components)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#list_components)
