@@ -19,6 +19,7 @@ from .literals import (
     ComponentTypeType,
     DiskImageFormatType,
     EbsVolumeTypeType,
+    ImageSourceType,
     ImageStatusType,
     ImageTypeType,
     OwnershipType,
@@ -639,6 +640,7 @@ ImageVersionTypeDef = TypedDict(
         "owner": str,
         "dateCreated": str,
         "buildType": BuildTypeType,
+        "imageSource": ImageSourceType,
     },
     total=False,
 )
@@ -1188,6 +1190,8 @@ ComponentSummaryTypeDef = TypedDict(
         "changeDescription": str,
         "dateCreated": str,
         "tags": Dict[str, str],
+        "publisher": str,
+        "obfuscate": bool,
     },
     total=False,
 )
@@ -1211,6 +1215,8 @@ ComponentTypeDef = TypedDict(
         "encrypted": bool,
         "dateCreated": str,
         "tags": Dict[str, str],
+        "publisher": str,
+        "obfuscate": bool,
     },
     total=False,
 )
@@ -1825,6 +1831,7 @@ ImageSummaryTypeDef = TypedDict(
         "outputResources": OutputResourcesTypeDef,
         "tags": Dict[str, str],
         "buildType": BuildTypeType,
+        "imageSource": ImageSourceType,
     },
     total=False,
 )
@@ -2043,6 +2050,7 @@ ImageTypeDef = TypedDict(
         "outputResources": OutputResourcesTypeDef,
         "tags": Dict[str, str],
         "buildType": BuildTypeType,
+        "imageSource": ImageSourceType,
     },
     total=False,
 )
